@@ -4,6 +4,7 @@
 #![allow(dead_code)]
 #![allow(unused_imports)]
 #![feature(alloc_error_handler)]
+#![feature(const_mut_refs)]
 #![feature(custom_test_frameworks)]
 #![feature(abi_x86_interrupt)]
 #![test_runner(crate::testexec)]
@@ -27,6 +28,7 @@ pub mod font;
 pub mod fs;
 pub mod gdt;
 pub mod intr;
+pub mod io;
 pub mod macros;
 pub mod math;
 pub mod mem;
@@ -34,6 +36,7 @@ pub mod noblkio;
 pub mod pic;
 pub mod rgx;
 pub mod ser;
+pub mod syscall;
 pub mod time;
 pub mod vgabuff;
 
